Struct passerine::common::source::Source [−][src]
Source represents some literal source code.
Whether a repl session, a file on disk, or some library code.
It’s essentially a string with a path, the path serving as the source’s name.
Source files without a path point to ./source,
though this behaviour might change in the future.
Fields
contents: Stringpath: PathBufImplementations
impl Source[src]
pub fn new(source: &str, path: PathBuf) -> Rc<Source>[src]
Creates a new Source given both an &str and a PathBuf.
Note that this function does not check that the contents of the file
match the source.
Source::path or Source::source should be used instead.
pub fn path(path: PathBuf) -> Result<Rc<Source>>[src]
Build a Source from a path.
This will read a file to create a new source.
pub fn source(source: &str) -> Rc<Source>[src]
Build an empty Source containing just a string.
Note that this source will point towards ./source.